@@ -14,6 +14,7 @@ import dask.array as da
 import h5py
 sys.path.append("../../pyUSID/")
 from pyUSID.io import dtype_utils
+from .data_utils import delete_existing_file
 
 struc_dtype = np.dtype({'names': ['r', 'g', 'b'],
                         'formats': [np.float32, np.uint16, np.float64]})
@@ -730,5 +731,41 @@ class TestValidateStringArgs(unittest.TestCase):
             _ = dtype_utils.validate_string_args(['a', 'v'], {'a': 1, 'v': 43})
 
 
+class TestLazyLoadArray(unittest.TestCase):
+
+    def test_dask_input(self):
+        arr = da.random.random(2, 3)
+        self.assertTrue(np.allclose(arr, dtype_utils.lazy_load_array(arr)))
+
+    def test_invalid_type(self):
+        with self.assertRaises(TypeError):
+            _ = dtype_utils.lazy_load_array([1, 2, 3])
+
+    def test_numpy(self):
+        np_arr = np.random.rand(2, 3)
+        da_arr = da.from_array(np_arr, chunks=np_arr.shape)
+        self.assertTrue(np.allclose(da_arr, dtype_utils.lazy_load_array(np_arr)))
+
+    def test_h5_dset_no_chunks(self):
+        h5_path = 'blah.h5'
+        delete_existing_file(h5_path)
+        with h5py.File(h5_path) as h5_f:
+            np_arr = np.random.rand(2, 3)
+            h5_dset = h5_f.create_dataset('Test', data=np_arr)
+            da_arr = da.from_array(np_arr, chunks=np_arr.shape)
+            self.assertTrue(np.allclose(da_arr, dtype_utils.lazy_load_array(h5_dset)))
+        os.remove(h5_path)
+
+    def test_h5_dset_w_chunks(self):
+        h5_path = 'blah.h5'
+        delete_existing_file(h5_path)
+        with h5py.File(h5_path) as h5_f:
+            np_arr = np.random.rand(200, 30)
+            h5_dset = h5_f.create_dataset('Test', data=np_arr, chunks=(1, 30))
+            da_arr = da.from_array(np_arr, chunks=h5_dset.chunks)
+            self.assertTrue(np.allclose(da_arr, dtype_utils.lazy_load_array(h5_dset)))
+        os.remove(h5_path)
+
+
 if __name__ == '__main__':
     unittest.main()
